using System;
using Autofac;
using FitConnect;
using FitConnect.Models;
using FluentAssertions;
using Microsoft.Extensions.Logging;
using MockContainer;
using NUnit.Framework;

namespace FluentApiTest;

public class FluentSenderTests {
    private IContainer _container = null!;
    protected string clientId = "20175c2b-c4dd-4a01-99b1-3a08436881a1";
    protected string clientSecret = "KV2qd7qc5n-xESB6dvfrTlMDx2BWHJd5hXJ6pKKnbEQ";
    private ILogger? logger;

    [OneTimeSetUp]
    public void OneTimeSetup() {
        _container = Container.Create();
        logger = _container.Resolve<ILogger>();
    }

    [SetUp]
    public void Setup() {
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_ArgumentExceptionLeikaKeyInvalid() {
        Assert.Throws<ArgumentException>(() => {
            new Sender(FitConnectEnvironment.Development,
                    clientId, clientSecret,
                    MockContainer.Container.Create())
                .WithDestination(Guid.NewGuid().ToString())
                .WithServiceType("", "")
                .WithAttachments(Array.Empty<Attachment>())
                .WithData("")
                .Submit();
        })!.Message.Should().Be("Invalid leika key");
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithData() {
        new Sender(FitConnectEnvironment.Development,
                clientId, clientSecret,
                MockContainer.Container.Create())
            .WithDestination(Guid.NewGuid().ToString())
            .WithServiceType("", "urn:de:fim:leika:leistung:99400048079000")
            .WithAttachments(Array.Empty<Attachment>())
            .WithData("")
            .Submit();
    }

    [Test]
    public void FluentSender_ShouldNotThrowAnError_MockingServicesWithoutData() {
        new Sender(FitConnectEnvironment.Development,
                clientId, clientSecret,
                Container.Create())
            .WithDestination(Guid.NewGuid().ToString())
            .WithServiceType("", "urn:de:fim:leika:leistung:99400048079000")
            .WithAttachments(Array.Empty<Attachment>())
            .Submit();
    }
}
